package cn.iocoder.yudao.module.order.service.orderItemPackLog;

import java.util.*;
import javax.validation.*;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.module.order.vo.orderItemPackLog.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderItemPackLog.OrderItemPackLogDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 入仓项打包纪录 Service 接口
 *
 * @author yanghao
 */
public interface OrderItemPackLogService extends IService<OrderItemPackLogDO> {

    /**
     * 创建入仓项打包纪录
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createItemPackLog(@Valid OrderItemPackLogCreateReqVO createReqVO);

    /**
     * 更新入仓项打包纪录
     * @param updateReqVO 更新信息
     */
    void updateItemPackLog(@Valid OrderItemPackLogUpdateReqVO updateReqVO);

    /**
     * 删除入仓项打包纪录
     * @param id 编号
     */
    void deleteItemPackLog(Long id);

    /**
     * 获得入仓项打包纪录
     * @param id 编号
     * @return 入仓项打包纪录
     */
    OrderItemPackLogDO getItemPackLog(Long id);

    /**
     * 获得入仓项打包纪录列表
     * @param ids 编号
     * @return 入仓项打包纪录列表
     */
    List<OrderItemPackLogDO> getItemPackLogList(Collection<Long> ids);

    /**
     * 获得入仓项打包纪录分页
     * @param page 分页查询
     * @param query 查询
     * @return 入仓项打包纪录分页
     */
    PageResult<OrderItemPackLogDO> getItemPackLogPage(OrderItemPackLogQueryVO query, PageVO page);

    /**
     * 获得入仓项打包纪录列表, 用于 Excel 导出
     * @param query 查询
     * @return 入仓项打包纪录列表
     */
    List<OrderItemPackLogDO> getItemPackLogList(OrderItemPackLogQueryVO query);


    /**
     * 获取最原始的入仓数据
     *
     * @param orderId 订单id
     * @return
     */
    List<OrderItemPackLogDO> getOriginalPackLogList(Long orderId);
}
